==> mercury-0.1.6.tar.gz: lib/src/session.dart <==
part of mercury;

/// A session for connecting to the Discord API.
class Session {
  /// The current Discord token.
  String token;

  /// The type of [token].
  TokenType tokenType;

  /// The current logger for this session.
  LoggerContext logger = new LoggerContext.root('DiscordSession');

  /// The w_transport transport platform to use for all requests.
  transport.TransportPlatform transportPlatform;

  /// The current WebSocket wrapper.
  _WebSocketSession _ws;

  /// The current REST wrapper.
  _RestSession _rest;

  /// The current event dispatcher.
  EventDispatcher dispatcher;

  /// The users that this client has received.
  _EntityCollection<User> users = new _EntityCollection();

  /// The guilds that this client has received.
  _EntityCollection<Guild> guilds = new _EntityCollection();

  // The private channels that this client has received.
  // I should do this sometime

  /// A mapping of channel IDs to guild IDs.
  Map<String, String> channelGuildMap = {};

  /// Creates a new [Session], with no authentication properties.
  Session(this.transportPlatform) {
    this._rest = new _RestSession(this);
    this._ws = new _WebSocketSession(this);
    this.dispatcher = new EventDispatcher(this);
  }

  /// Sets the current token and type.
  void setToken(String token, TokenType type) {
    this.token = token;
    this.tokenType = type;
  }

  /// Signals the WebSocket to connect and begin reading and sending messages.
  Future connect() async {
    await this._ws.connect();
  }

  /// Disconnects from the WebSocket connection.
  void stop() {
    this._ws.stop();
  }

  /// Retrieves a channel from the entity caches.
  EntityCollectionEntry<ChannelBase> getChannel(String channelId) {
    if (channelId == null || channelId.isEmpty)
      throw new ArgumentError(
          'Argument channelId (got: ${channelId}) cannot be empty or null.');

    if (this.channelGuildMap[channelId] != null) {
      var gEntry = getGuild(channelGuildMap[channelId]);
      var value = gEntry.value;
      return (value.channels.get(channelId));
    }

    return null;
  }

  /// Retrieves a guild from the entity cache.
  EntityCollectionEntry<Guild> getGuild(String guildId) {
    if (guildId == null || guildId.isEmpty)
      throw new ArgumentError(
          'Argument guildId (got: ${guildId}) cannot be empty or null.');

    return this.guilds.get(guildId);
  }
}

==> mercury-0.2.0.tar.gz: lib/src/session.dart <==
part of mercury;

/// A session for connecting to the Discord API.
class Session {
  /// The current Discord token.
  String token;

  /// The type of [token].
  TokenType tokenType;

  /// The current logger for this session.
  LoggerContext logger = new LoggerContext.root('DiscordSession');

  /// The w_transport transport platform to use for all requests.
  transport.TransportPlatform transportPlatform;

  /// The current WebSocket wrapper.
  _WebSocketSession _ws;

  /// The current REST wrapper.
  _RestSession _rest;

  /// The current event dispatcher.
  EventDispatcher dispatcher;

  /// The users that this client has received.
  _EntityCollection<User> users = new _EntityCollection();

  /// The guilds that this client has received.
  _EntityCollection<Guild> guilds = new _EntityCollection();

  // The private channels that this client has received.
  // I should do this sometime

  /// A mapping of channel IDs to guild IDs.
  Map<String, String> channelGuildMap = {};

  /// Creates a new [Session], with no authentication properties.
  Session(this.transportPlatform) {
    this._rest = new _RestSession(this);
    this._ws = new _WebSocketSession(this);
    this.dispatcher = new EventDispatcher(this);
  }

  /// Sets the current token and type.
  void setToken(String token, TokenType type) {
    this.token = token;
    this.tokenType = type;
  }

  /// Signals the WebSocket to connect and begin reading and sending messages.
  Future connect() async {
    await this._ws.connect();
  }

  /// Disconnects from the WebSocket connection.
  void stop() {
    this._ws.stop();
  }

  /// Retrieves a channel from the entity caches.
  EntityCollectionEntry<ChannelBase> getCachedChannel(String channelId) {
    if (channelId == null || channelId.isEmpty)
      throw new ArgumentError(
          'Argument channelId (got: ${channelId}) cannot be empty or null.');

    if (this.channelGuildMap[channelId] != null) {
      var gEntry = getCachedGuild(channelGuildMap[channelId]);
      var value = gEntry.value;
      return (value.channels.get(channelId));
    }

    return null;
  }

  /// Retrieves a guild from the entity cache.
  EntityCollectionEntry<Guild> getCachedGuild(String guildId) {
    if (guildId == null || guildId.isEmpty)
      throw new ArgumentError(
          'Argument guildId (got: ${guildId}) cannot be empty or null.');

    return this.guilds.get(guildId);
  }
}
